==> myfaces-tobago-4.5.5-source-release.zip: tobago-4.5.5/tobago-core/src/main/java/org/apache/myfaces/tobago/event/SheetAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.event;

import org.apache.myfaces.tobago.internal.util.StringUtils;

public enum SheetAction {

  /**
   * First page is requested
   */
  first,

  /**
   * Previous page is requested
   */
  prev,

  /**
   * Next page is requested
   */
  next,

  /**
   * Last page is requested
   */
  last,

  /**
   * A specified row is requested
   */
  toRow,

  /**
   * A specified page is requested
   */
  toPage,

  /**
   * Sorting
   */
  sort,

  /**
   * A lazy load is requested
   */
  lazy;

  private String bundleKey;

  SheetAction() {
    this.bundleKey = "sheet" + StringUtils.firstToUpperCase(name());
  }

  public String getBundleKey() {
    return bundleKey;
  }
}

==> myfaces-tobago-5.7.0-source-release.zip: tobago-5.7.0/tobago-core/src/main/java/org/apache/myfaces/tobago/event/SheetAction.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.event;

public enum SheetAction {

  /**
   * First page is requested
   */
  first("sheet.first"),

  /**
   * Previous page is requested
   */
  prev("sheet.prev"),

  /**
   * Next page is requested
   */
  next("sheet.next"),

  /**
   * Last page is requested
   */
  last("sheet.last"),

  /**
   * A specified row is requested
   */
  toRow,

  /**
   * A specified page is requested
   */
  toPage("sheet.toPage"),

  /**
   * Sorting
   */
  sort,

  /**
   * A lazy load is requested
   */
  lazy;

  private String bundleKey;

  SheetAction() {
  }

  SheetAction(final String bundleKey) {
    this.bundleKey = bundleKey;
  }

  public String getBundleKey() {
    return bundleKey;
  }
}
